SystemOrganization addCategory: #GODAcademics!

GODData subclass: #ACADAttribute
	instanceVariableNames: 'value filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

!ACADAttribute methodsFor: 'initialize' stamp: 'rmc 10/17/2014 01:18'!
from: aText start: aStartString end: anEndString at: aPosition
	"Initializes a new attribute that is between the given strings"
	value := (filter from: aText start: aStartString end: anEndString) at: aPosition.
	 ^self! !

!ACADAttribute methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:06'!
value
	"returns the value of this attribute"

	^value.! !

!ACADAttribute methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:29'!
value: aString
	"sets the value of this attribute"

	value := aString.! !

GODData subclass: #ACADPaper
	instanceVariableNames: 'name coauthors journal numberOfCitations year impactFactor tagPool'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:20'!
coauthors
	"returns a collection of ACADAttributes refering to the coauthors"

		^coauthors value.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/16/2014 22:25'!
coauthors: aString
	"sets the coauthors of this paper"

	coauthors := ACADAttribute new value: aString.

! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/17/2014 12:07'!
findImpactFactor
	"searches the qualisList for the name of this paper's journal"

	|qualisList|
	qualisList := ACADQualis uniqueInstance qualisList.

	"this does not make total sense. If we had a dictionary for the qualis list, it would be better"
	self impactFactor: (ACADAttribute from: qualisList start: journal end: 'bla2 ' at: 1). 
! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/16/2014 16:57'!
impactFactor
	"get the impact factor"

	^impactFactor value.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/16/2014 16:57'!
impactFactor: aString
	"sets the impact factor"

	impactFactor := ACADAttribute new value: aString.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:10'!
journal
	"returns the journal that published this paper"

	^journal value.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/12/2014 12:38'!
journal: aString
	"sets this paper's journal"

	journal := ACADAttribute new value: aString.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/16/2014 22:27'!
name
	"gets this paper's name"

	^name value.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/17/2014 15:15'!
name: aString
	"sets this paper's name"

	name := ACADAttribute new value: aString.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:18'!
numberOfCitations
	"returns the number of citations of the paper"

	^numberOfCitations value. ! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/12/2014 12:39'!
numberOfCitations: aString
	"sets the numberOfCitations atrribute"

	numberOfCitations := ACADAttribute new value: aString.! !

!ACADPaper methodsFor: 'initialize' stamp: 'rmc 10/17/2014 16:50'!
withPaper: aHtmlPaper
	"builds a paper"

	tagPool := ACADTagPool singleton.
	
	name := (tagPool getAttributes: 'ACADPaper>name' from: aHtmlPaper) at: 1.
	coauthors := (tagPool getAttributes: 'ACADPaper>coauthors' from: aHtmlPaper) at: 1.
	journal := (tagPool getAttributes: 'ACADPaper>journal' from: aHtmlPaper) at: 1.
	year := (tagPool getAttributes: 'ACADPaper>year' from: aHtmlPaper) at: 2.
	numberOfCitations := (tagPool getAttributes: 'ACADPaper>numberOfCitations' from: aHtmlPaper) at: 1.

	"self addOnLayoutGrid: name at: 1 at: 1.
	self addOnLayoutGrid: coauthors at: 2 at: 1.
	self addOnLayoutGrid: journal at: 3 at: 1.
	self addOnLayoutGrid: year at: 4 at: 1.
	self addOnLayoutGrid: numberOfCitations at: 5 at: 1."! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:16'!
year
	"returns the ACADAttribute corresponding to the year attribute"

	^year value.! !

!ACADPaper methodsFor: 'accessing' stamp: 'rmc 10/17/2014 15:16'!
year: aString
	"sets the year attribute"

	year := ACADAttribute new value: aString.! !

GODData subclass: #ACADResearcher
	instanceVariableNames: 'name job papers tagPool'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

!ACADResearcher methodsFor: 'processing' stamp: 'ib 10/17/2014 18:16'!
forEachPaperDo: aBlock
	papers do: [ :p |
		aBlock value: p value]! !

!ACADResearcher methodsFor: 'initialize' stamp: 'rmc 10/17/2014 17:02'!
initialize
	"allocs memory for the attributes"

	papers := OrderedCollection new.! !

!ACADResearcher methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:24'!
job
	"returns the job of the researcher"

	^job value.! !

!ACADResearcher methodsFor: 'accessing' stamp: 'rmc 10/12/2014 13:28'!
job: aString
	"sets the researcher's job attribute"

	job := ACADAttribute new value: aString.! !

!ACADResearcher methodsFor: 'accessing' stamp: 'ib 10/17/2014 16:21'!
name
	^name value! !

!ACADResearcher methodsFor: 'accessing' stamp: 'ib 10/17/2014 16:19'!
name: aString
	name := aString! !

!ACADResearcher methodsFor: 'initialize' stamp: 'rmc 10/17/2014 17:07'!
new
	"creates new instance"

	^super new initialize.! !

!ACADResearcher methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:26'!
papers
	"returns a collection of papers"

	^papers.! !

!ACADResearcher methodsFor: 'accessing' stamp: 'rmc 10/11/2014 22:27'!
papers: aCollectionOfPapers
	"sets the researchers collection of papers"

	papers := aCollectionOfPapers.! !

!ACADResearcher methodsFor: 'processing' stamp: 'rmc 10/17/2014 20:05'!
papersByImpactDict
	"returns a sheet with two collums. The first contains the impact factors
	 and the second the number of papers with that impact"
	|table|

	table := Dictionary new.	
	#('A1' 'A2' 'B1' 'B2' 'B3' 'B4' 'B5' 'C') do: [:each | table at: each put: 0].

	self forEachPaperDo: [:paper | |impFac|
							impFac := paper impactFactor.
							table at: impFac put: ((table at: impFac) + 1). ].
	^table.! !

!ACADResearcher methodsFor: 'processing' stamp: 'ib 10/17/2014 18:13'!
totalNumberOfCitations
	| total |
	total := 0.
	self forEachPaperDo: [:paper | total := total + paper numberOfCitations value asInteger].
	^total! !

!ACADResearcher methodsFor: 'initialize' stamp: 'rmc 10/17/2014 21:56'!
withPage: aHtmlPage
	"this method fills a researcher's fields. It first tries to find its attributes using the filter,
	 then it asks for the filter for a collection of htmlPapers, and for each of these, it
	 creates a new AcadPaper and add it to the grid"

	|htmlPapers index|

	tagPool := ACADTagPool singleton.

	name := (tagPool getAttributes: 'ACADResearcher>name' from: aHtmlPage) at: 1.
	job := (tagPool getAttributes: 'ACADResearcher>job' from: aHtmlPage) at: 1.

	"self addOnLayoutGrid: name at: 1 at: 1." "dont know what these indexes mean exactly"
	"self addOnLayoutGrid: job at: 2 at: 1."

	htmlPapers := tagPool getAttributes: 'ACADResearcher>papers' from: aHtmlPage.

	htmlPapers do: [:each | papers add: (ACADPaper new withPaper: (each value))]. "Each paper will set up itself"

	index := 3.
	papers do: [:each | "self addOnLayoutGrid: each at: index at: 1."
					     index := index + 1].
	! !

Object subclass: #ACADAcademics
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

!ACADAcademics methodsFor: 'web-interaction' stamp: 'rmc 10/5/2014 11:39'!
acadIndexPage
	"we generate our form and ask the web to exhibe it?
	 We still don't know how this is going to work exactly"
	
	"here we generate our form"

	"here we ask to the web to display it"
	"WebGenarator new generateAcadIndexPage"
	^self notYetImplemented.! !

!ACADAcademics methodsFor: 'web-interaction' stamp: 'rmc 10/17/2014 12:55'!
submitForm: aGoogleScholarProfileLink
	"Main message that will start the whole process"
	"|webPage htmlPage researcher dict image webPageAnswer|

	webPage := WebPageFetcher new getInformation: aGoogleScholarLink.
	htmlPage := webPage html.
	researcher := ACADResearcher new withPage: htmlPage
	
	image := GGBarGraph new generateGraphWithDict: (researcher papersByImpactDict.).
	 
	webPageAnswer addOnLayoutGrid: reasearcher at: 1 at: 1.
	webPageAnswer addOnLayoutGrid: image at: 2 at: 1.

	WEBPageGenerator new generate: webPageAnswer.
	"	
	^self notYetImplemented
	! !

Object subclass: #ACADQualis
	instanceVariableNames: 'qualisList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

ACADQualis class
	instanceVariableNames: 'uniqueInstance'!

ACADQualis class
	instanceVariableNames: 'uniqueInstance'!

!ACADQualis class methodsFor: 'instance creation' stamp: 'rmc 10/17/2014 00:47'!
new
	
	self error: 'should use uniqueInstance'.! !

!ACADQualis class methodsFor: 'instance creation' stamp: 'rmc 10/17/2014 00:57'!
uniqueInstance
	"returns the uniqueInstance of this class"

	uniqueInstance isNil
		ifTrue: [uniqueInstance := self basicNew initialize].

	^uniqueInstance.

	! !

!ACADQualis methodsFor: 'initialize-release' stamp: 'rmc 10/17/2014 01:12'!
initialize
	"loads the file"

	self qualisList: 'path to the file'.
	! !

!ACADQualis methodsFor: 'accessing' stamp: 'rmc 10/17/2014 00:53'!
qualisList
	"get the qualisList"

	^qualisList.! !

!ACADQualis methodsFor: 'accessing' stamp: 'rmc 10/17/2014 01:44'!
qualisList: aPathToFile
	"sets the qualis list"

	qualisList := 'get the text using the path somehow'.! !

Object subclass: #ACADTag
	instanceVariableNames: 'start end'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

ACADTag class
	instanceVariableNames: 'pool'!

ACADTag class
	instanceVariableNames: 'pool'!

!ACADTag methodsFor: 'accessing' stamp: 'ib 10/16/2014 17:55'!
end
	^end! !

!ACADTag methodsFor: 'accessing' stamp: 'ib 10/16/2014 18:04'!
end: anEndPosition
	end := anEndPosition.
	^self! !

!ACADTag methodsFor: 'accessing' stamp: 'ib 10/16/2014 17:55'!
start
	^start! !

!ACADTag methodsFor: 'accessing' stamp: 'ib 10/16/2014 18:04'!
start: aStartTag
	start := aStartTag.
	^self! !

Object subclass: #ACADTagPool
	instanceVariableNames: 'pool filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademics'!

ACADTagPool class
	instanceVariableNames: 'uniqueInstance'!

ACADTagPool class
	instanceVariableNames: 'uniqueInstance'!

!ACADTagPool class methodsFor: 'instance creation' stamp: 'ib 10/17/2014 15:48'!
clear
	uniqueInstance := nil.! !

!ACADTagPool class methodsFor: 'instance creation' stamp: 'ib 10/17/2014 15:48'!
singleton
	uniqueInstance ifNil: [uniqueInstance := self new initialize].
	^uniqueInstance! !

!ACADTagPool methodsFor: 'accessing' stamp: 'ib 10/16/2014 18:21'!
get: aTagName
	^pool at: aTagName! !

!ACADTagPool methodsFor: 'accessing' stamp: 'ib 10/16/2014 20:23'!
getAttributes: aTagName from: aHTML
	| tag aCollection |
	tag := pool at: aTagName.
	aCollection := OrderedCollection new.
	(filter from: aHTML start: (tag start) end: (tag end)) do: [:v | 
		aCollection add: (ACADAttribute new value: v)].
	^aCollection! !

!ACADTagPool methodsFor: 'initialize-release' stamp: 'ib 10/17/2014 15:29'!
initialize
	pool := Dictionary new.
	pool at: 'ACADResearcher>name' put: (ACADTag new start: '<div id="gsc_prf_in">'; end: '</div>').
	pool at: 'ACADResearcher>papers' put: (ACADTag new start: '<tr class="gsc_a_tr>'; end: '</tr>').
	pool at: 'ACADResearcher>job' put: (ACADTag new start: '<div class="gsc_prf_il">'; end: '</div>').

	pool at: 'ACADPaper>name' put: (ACADTag new start: 'class="gsc_a_at">'; end: '</a>').
	pool at: 'ACADPaper>coauthors' put: (ACADTag new start: '<div class="gs_gray">'; end: '</div>').
	pool at: 'ACADPaper>journal' put: (ACADTag new start: '<div class="gs_gray">'; end: '<span class="gs_oph">').
	pool at: 'ACADPaper>numberOfCitations' put: (ACADTag new start: 'class="gsc_a_ac">'; end: '</a>').
	pool at: 'ACADPaper>year' put: (ACADTag new start: '<span class="gsc_a_h">'; end: '</span>').! !
